pub struct Context { /* private fields */ }Implementations
Sourceimpl Context
impl Context
pub fn init( mode: Mode, matrix_storage_format: MatrixStorageFormat, ) -> Result<Arc<Self>, SparseLinearAlgebraError>
Sourcepub fn init_default() -> Result<Arc<Self>, SparseLinearAlgebraError>
pub fn init_default() -> Result<Arc<Self>, SparseLinearAlgebraError>
Sets MatrixStorageFormat::ByRow
Sourcepub unsafe fn init_with_allocator(
mode: Mode,
matrix_storage_format: MatrixStorageFormat,
allocator: MemoryAllocator,
) -> Result<Arc<Self>, SparseLinearAlgebraError>
pub unsafe fn init_with_allocator( mode: Mode, matrix_storage_format: MatrixStorageFormat, allocator: MemoryAllocator, ) -> Result<Arc<Self>, SparseLinearAlgebraError>
Initialise GraphBLAS with a custom memory allocator.
Panics / UB
The allocator passed here must be the same allocator that is set as the Rust global allocator. Mixing them will cause heap corruption.
pub fn call_without_detailed_error_information<F>( &self, function_to_call: F, ) -> Result<Status, SparseLinearAlgebraError>